@@ -419,7 +419,7 @@ int PREFIX(scanEndTag)(const ENCODING *enc, const char *ptr, const char *end,
 	}
       }
       return XML_TOK_PARTIAL;
-#ifdef XMLNS
+#ifdef XML_NS
     case BT_COLON:
       /* no need to check qname syntax here, since end-tag must match exactly */
       ptr += MINBPC(enc);
@@ -536,13 +536,13 @@ static
 int PREFIX(scanAtts)(const ENCODING *enc, const char *ptr, const char *end,
 		     const char **nextTokPtr)
 {
-#ifdef XMLNS
+#ifdef XML_NS
   int hadColon = 0;
 #endif
   while (ptr != end) {
     switch (BYTE_TYPE(enc, ptr)) {
     CHECK_NAME_CASES(enc, ptr, end, nextTokPtr)
-#ifdef XMLNS
+#ifdef XML_NS
     case BT_COLON:
       if (hadColon) {
 	*nextTokPtr = ptr;
@@ -584,7 +584,7 @@ int PREFIX(scanAtts)(const ENCODING *enc, const char *ptr, const char *end,
     case BT_EQUALS:
       {
 	int open;
-#ifdef XMLNS
+#ifdef XML_NS
 	hadColon = 0;
 #endif
 	for (;;) {
@@ -696,7 +696,7 @@ static
 int PREFIX(scanLt)(const ENCODING *enc, const char *ptr, const char *end,
 		   const char **nextTokPtr)
 {
-#ifdef XMLNS
+#ifdef XML_NS
   int hadColon;
 #endif
   if (ptr == end)
@@ -722,14 +722,14 @@ int PREFIX(scanLt)(const ENCODING *enc, const char *ptr, const char *end,
     *nextTokPtr = ptr;
     return XML_TOK_INVALID;
   }
-#ifdef XMLNS
+#ifdef XML_NS
   hadColon = 0;
 #endif
   /* we have a start-tag */
   while (ptr != end) {
     switch (BYTE_TYPE(enc, ptr)) {
     CHECK_NAME_CASES(enc, ptr, end, nextTokPtr)
-#ifdef XMLNS
+#ifdef XML_NS
     case BT_COLON:
       if (hadColon) {
 	*nextTokPtr = ptr;
@@ -1126,7 +1126,7 @@ int PREFIX(prologTok)(const ENCODING *enc, const char *ptr, const char *end,
   case BT_DIGIT:
   case BT_NAME:
   case BT_MINUS:
-#ifdef XMLNS
+#ifdef XML_NS
   case BT_COLON:
 #endif
     tok = XML_TOK_NMTOKEN;
@@ -1156,7 +1156,7 @@ int PREFIX(prologTok)(const ENCODING *enc, const char *ptr, const char *end,
     case BT_S: case BT_CR: case BT_LF:
       *nextTokPtr = ptr;
       return tok;
-#ifdef XMLNS
+#ifdef XML_NS
     case BT_COLON:
       ptr += MINBPC(enc);
       switch (tok) {
@@ -1342,7 +1342,7 @@ int PREFIX(isPublicId)(const ENCODING *enc, const char *ptr, const char *end,
     case BT_AST:
     case BT_PERCNT:
     case BT_NUM:
-#ifdef XMLNS
+#ifdef XML_NS
     case BT_COLON:
 #endif
       break;
@@ -1413,7 +1413,8 @@ int PREFIX(getAtts)(const ENCODING *enc, const char *ptr,
       else if (open == BT_QUOT) {
         state = other;
 	if (nAtts < attsMax)
-	  atts[nAtts++].valueEnd = ptr;
+	  atts[nAtts].valueEnd = ptr;
+	nAtts++;
       }
       break;
     case BT_APOS:
@@ -1426,7 +1427,8 @@ int PREFIX(getAtts)(const ENCODING *enc, const char *ptr,
       else if (open == BT_APOS) {
         state = other;
 	if (nAtts < attsMax)
-	  atts[nAtts++].valueEnd = ptr;
+	  atts[nAtts].valueEnd = ptr;
+	nAtts++;
       }
       break;
     case BT_AMP:
@@ -1508,8 +1510,8 @@ int PREFIX(charRefNumber)(const ENCODING *enc, const char *ptr)
 static
 int PREFIX(predefinedEntityName)(const ENCODING *enc, const char *ptr, const char *end)
 {
-  switch (end - ptr) {
-  case 2 * MINBPC(enc):
+  switch ((end - ptr)/MINBPC(enc)) {
+  case 2:
     if (CHAR_MATCHES(enc, ptr + MINBPC(enc), 't')) {
       switch (BYTE_TO_ASCII(enc, ptr)) {
       case 'l':
@@ -1519,7 +1521,7 @@ int PREFIX(predefinedEntityName)(const ENCODING *enc, const char *ptr, const cha
       }
     }
     break;
-  case 3 * MINBPC(enc):
+  case 3:
     if (CHAR_MATCHES(enc, ptr, 'a')) {
       ptr += MINBPC(enc);
       if (CHAR_MATCHES(enc, ptr, 'm')) {
@@ -1529,7 +1531,7 @@ int PREFIX(predefinedEntityName)(const ENCODING *enc, const char *ptr, const cha
       }
     }
     break;
-  case 4 * MINBPC(enc):
+  case 4:
     switch (BYTE_TO_ASCII(enc, ptr)) {
     case 'q':
       ptr += MINBPC(enc);
@@ -1575,7 +1577,7 @@ int PREFIX(sameName)(const ENCODING *enc, const char *ptr1, const char *ptr2)
       break;
     case BT_NONASCII:
     case BT_NMSTRT:
-#ifdef XMLNS
+#ifdef XML_NS
     case BT_COLON:
 #endif
     case BT_HEX:
@@ -1606,7 +1608,7 @@ int PREFIX(sameName)(const ENCODING *enc, const char *ptr1, const char *ptr2)
       case BT_LEAD4:
       case BT_NONASCII:
       case BT_NMSTRT:
-#ifdef XMLNS
+#ifdef XML_NS
       case BT_COLON:
 #endif
       case BT_HEX:
@@ -1626,7 +1628,7 @@ static
 int PREFIX(nameMatchesAscii)(const ENCODING *enc, const char *ptr1, const char *ptr2)
 {
   for (; *ptr2; ptr1 += MINBPC(enc), ptr2++) {
-    if (!CHAR_MATCHES(end, ptr1, *ptr2))
+    if (!CHAR_MATCHES(enc, ptr1, *ptr2))
       return 0;
   }
   switch (BYTE_TYPE(enc, ptr1)) {
@@ -1635,7 +1637,7 @@ int PREFIX(nameMatchesAscii)(const ENCODING *enc, const char *ptr1, const char *
   case BT_LEAD4:
   case BT_NONASCII:
   case BT_NMSTRT:
-#ifdef XMLNS
+#ifdef XML_NS
   case BT_COLON:
 #endif
   case BT_HEX:
@@ -1660,7 +1662,7 @@ int PREFIX(nameLength)(const ENCODING *enc, const char *ptr)
 #undef LEAD_CASE
     case BT_NONASCII:
     case BT_NMSTRT:
-#ifdef XMLNS
+#ifdef XML_NS
     case BT_COLON:
 #endif
     case BT_HEX:
